@@ -9,10 +9,10 @@
 #' 
 #' @export
 #' @examples
-#' interval(t.test(rnorm(100)))
+#' confint(t.test(rnorm(100)))
 #' pval(t.test(rnorm(100)))
 #' stat(t.test(rnorm(100)))
-#' interval(var.test(rnorm(10,sd=1), rnorm(20, sd=2)))
+#' confint(var.test(rnorm(10,sd=1), rnorm(20, sd=2)))
 #' pval(var.test(rnorm(10,sd=1), rnorm(20, sd=2)))
 #' 
 #' data(HELPrct)
@@ -24,31 +24,39 @@
 #' @keywords inference 
 #' 
 
-interval <- function(x, ...){UseMethod("interval", x)}
-
 #' @rdname interval
-#' @method interval htest
+#' @param object a fitted model object or an htest object.
+#' @param parm a specification of which parameters are to be given confidence intervals, 
+#' either a vector of numbers or a vector of names. If missing, all parameters are considered.
+#' @param level the confidence level required.
+
+interval <- confint
+
+# interval <- (x, ...){UseMethod("interval", x)}
+#
+#' @rdname interval
+#' @method confint htest
 #' @param verbose a logical
-interval.htest <- function (x, verbose=FALSE, ...){
-  int <- x$conf.int
+
+confint.htest <- function (object, parm, level, ...){
+  if (! missing( parm ) || !missing( level ) ) { warning("parm and level are ignored.") }
+  int <- object$conf.int
   lev <- attr(int, "conf.level")
-  if (verbose ) {
-	  cat( "\n" )
-	  cat('Method: ')
-	  cat(x$method)
-	  cat( "\n" )
-	  cat( "\n" )
-	  print(x$estimate) 
-	  cat( "\n" )
-	  cat( paste(lev * 100, "% confidence interval: \n", sep = "") )
-	  cat( as.vector(int) )
-	  cat( "\n" )
-	  cat( "\n" )
-  	  invisible(int)
+  verbose <- list(...)[['verbose']]
+  if (is.null(verbose)) verbose <- FALSE
+  if ( verbose ) {
+	  message('\nMethod: ')
+	  message(object$method)
+	  message('\nEstimate: ')
+	  message( format(object$estimate, getOption('digits',3)) )
+	  message( paste("\n", lev * 100, "% confidence interval: ", sep = "") )
+	  message( paste(format(as.vector(int), getOption('digits',3)), collapse=" ") )
+  	  return(invisible(int))
   }
   interv <- as.vector(int) 
   names(interv) <- c('lower','upper')
-  int <- c(x$estimate, interv )
+  level <- c(level=lev)
+  int <- c(object$estimate, interv, level )
   return(int)
 }
 
@@ -106,7 +114,7 @@ pval.htest <- function (x, digits=4, verbose=FALSE, ...){
 	  cat(')\n\n')
 	  cat( paste("p-value = ", signif(pval,digits), sep="") ) 
 	  cat('\n\n')
-	  invisible(pval)
+	  return(invisible(pval))
   }
 
   return( c(p.value=pval) )
