@@ -78,7 +78,7 @@ function (q, mean = 0, sd = 1, plot = TRUE, verbose = TRUE, invisible=FALSE, dig
 		      vlwd=vlwd, vcol=vcol, rot=rot, ...))
     }
 	if (invisible) { 
-    	invisible(pnorm(q, mean = mean, sd = sd, lower.tail = lower.tail, log.p = log.p))
+    	return(invisible(pnorm(q, mean = mean, sd = sd, lower.tail = lower.tail, log.p = log.p)))
 	}
     return(pnorm(q, mean = mean, sd = sd, lower.tail = lower.tail, log.p = log.p))
 }
@@ -108,7 +108,7 @@ function (p, mean = 0, sd = 1, plot = TRUE, verbose = TRUE, digits = 4,
 		      vlwd=vlwd, vcol=vcol, rot=rot, ...))
     }
 	if (invisible) { 
-    	invisible(q)
+    		return(invisible(q))
 	}
     return(q)
 }
